import 'package:flutter/material.dart';

enum AnimationType { normal, fadeIn }

class RouteTransitions {
  final BuildContext context;
  final Widget child;
  final AnimationType animation;
  final Duration duration;
  final bool replacement;

  RouteTransitions(
      {@required this.context,
      @required this.child,
      this.animation = AnimationType.normal,
      this.duration = const Duration(milliseconds: 300),
      this.replacement = false}) {
    switch (this.animation) {
      case AnimationType.normal:
        this._navigationNormal();
        break;
      case AnimationType.fadeIn:
        this._fadeInTransition();
        break;
    }
  }

  void _pushName(Route route) => Navigator.push(context, route);

  void _pushReplacementName(Route route) =>
      Navigator.pushReplacement(context, route);

  void _navigationNormal() {
    final route = MaterialPageRoute(builder: (_) => this.child);

    (this.replacement) ? _pushReplacementName(route) : _pushName(route);
  }

  void _fadeInTransition() {
    final route = PageRouteBuilder(
      pageBuilder: (
        _,
        __,
        ___,
      ) =>
          this.child,
      transitionDuration: this.duration,
      transitionsBuilder: (_, animation, __, child) {
        return FadeTransition(
            child: child,
            opacity: Tween(begin: 0.0, end: 1.0).animate(
                CurvedAnimation(parent: animation, curve: Curves.easeOut)));
      },
    );
    (this.replacement) ? _pushReplacementName(route) : _pushName(route);
  }
}
